Serve

Struct Serve 

pub struct Serve<L, M, S> { /* private fields */ }
Future returned by serve.

Implementations



impl<L, M, S> Serve<L, M, S>
where L: Listener,

pub fn with_graceful_shutdown<F>( self, signal: F, ) -> WithGracefulShutdown<L, M, S, F>
where F: Future<Output = ()> + Send + 'static,

Prepares a server to handle graceful shutdown when the provided future completes.

Example
use axum::{Router, routing::get};

let router = Router::new().route("/", get(|| async { "Hello, World!" }));

let listener = tokio::net::TcpListener::bind("0.0.0.0:3000").await.unwrap();
axum::serve(listener, router)
    .with_graceful_shutdown(shutdown_signal())
    .await
    .unwrap();

async fn shutdown_signal() {
    // ...
}
Return Value

Similarly to serve, although this future resolves to io::Result<()>, it will never error. It returns Ok(()) only after the signal future completes.

pub fn local_addr(&self) -> Result<<L as Listener>::Addr, Error>

Returns the local address this server is bound to.